# -*- coding: UTF-8 -*-

from django.apps import AppConfig


class DictionaryConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'xj_dictionary'
    verbose_name = u'Ⅶ 字典模块'
    sort = 7
